@@ -1,8 +1,10 @@
-const marked = require('../');
+import { marked } from '../src/marked.js';
+import { createRequire } from 'node:module';
+const require = createRequire(import.meta.url);
 const version = require('../package.json').version;
 const name = 'Marked';
 
-module.exports = (req, res) => {
+export default function dingus(req, res) {
   if (req.method !== 'GET') {
     return res.status(405).json({
       error: {
@@ -14,4 +16,4 @@ module.exports = (req, res) => {
   const { text = '' } = req.query;
   const html = marked(text);
   res.json({ name, version, html });
-};
+}
